@@ -69,6 +69,10 @@
 #'@param devel Enable development mode (used for development of the format
 #'  itself, not useful for users of the format).
 #'
+#'@param resize_reload Disable the auto-reloading behavior when the window is resized.
+#' Useful when debugging large flexdashboard applications and this functionality
+#' is not needed.
+#'
 #'@param ... Unused
 #'
 #'@details See the flexdashboard website for additional documentation:
@@ -114,6 +118,7 @@ flex_dashboard <- function(fig_width = 6.0,
                            md_extensions = NULL,
                            pandoc_args = NULL,
                            devel = FALSE,
+                           resize_reload = TRUE,
                            ...) {
 
   # manage list of exit_actions (backing out changes to knitr options)
@@ -163,6 +168,12 @@ flex_dashboard <- function(fig_width = 6.0,
   else if (identical(theme, "bootstrap"))
     theme <- "default"
 
+  # resolve auto_reload
+  if (resize_reload == 'no' | grepl("fa?l?s?e?", resize_reload, ignore.case = T))
+    resize_reload <- F
+  else
+    resize_reload <- T
+
   # determine knitr options
   knitr_options <- knitr_options_html(fig_width = fig_width,
                                       fig_height = fig_height,
@@ -352,7 +363,8 @@ flex_dashboard <- function(fig_width = 6.0,
        paste0('    defaultFigWidth: ', figSizePixels(fig_width), ','),
        paste0('    defaultFigHeight: ', figSizePixels(fig_height), ','),
        paste0('    defaultFigWidthMobile: ', figSizePixels(fig_mobile[[1]]), ','),
-       paste0('    defaultFigHeightMobile: ', figSizePixels(fig_mobile[[2]])),
+       paste0('    defaultFigHeightMobile: ', figSizePixels(fig_mobile[[2]]), ','),
+       paste0('    resize_reload: ', ifelse(resize_reload,'true','false')),
        '  });',
        '});',
        '</script>'
@@ -564,7 +576,7 @@ navbar_dependencies <- function(navbar) {
 
   for (item in navbar) {
     if (!is.null(item$icon)) {
-      if (grepl('^fa-', item$icon))
+      if (grepl('fa-', item$icon))
         font_awesome <- TRUE
       if (grepl('^ion-', item$icon))
         ionicons <- TRUE
